//
// Created by depa on 3/10/2020.
//

#include "dataMgr.h"

dataMgr::dataMgr() {
    //
}

dataMgr::~dataMgr() {
    //
}

//! \brief mergeHeader - merges in input file header keywords provided in map, saves in new FITS file and provides its
//!                      name in output string
//! \param _inFitsFilename
//! \param _mapFitsKeywords
//! \param _outFitsFilename
//! \return EXIT_SUCCESS or EXIT_FAILURE
int dataMgr::mergeHeader(const std::string &_inFitsFilename, const std::map <std::string, std::string> &_mapFitsKeywords,
                         std::string &_outFitsFilename)
                         {
    // read FITS header
    // create FITS header to be merged
    // merge the two headers
    // create a new file with data + new header
    // save filename in out parameter
                         }
